@@ -19,14 +19,18 @@ from typing import Dict, Type
 from .base import OsConfigServiceTransport
 from .grpc import OsConfigServiceGrpcTransport
 from .grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
+from .rest import OsConfigServiceRestInterceptor, OsConfigServiceRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[OsConfigServiceTransport]]
 _transport_registry["grpc"] = OsConfigServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = OsConfigServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = OsConfigServiceRestTransport
 
 __all__ = (
     "OsConfigServiceTransport",
     "OsConfigServiceGrpcTransport",
     "OsConfigServiceGrpcAsyncIOTransport",
+    "OsConfigServiceRestTransport",
+    "OsConfigServiceRestInterceptor",
 )
