@@ -64,6 +64,7 @@ from google.cloud.osconfig_v1.types import (
 from .transports.base import DEFAULT_CLIENT_INFO, OsConfigZonalServiceTransport
 from .transports.grpc import OsConfigZonalServiceGrpcTransport
 from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
+from .transports.rest import OsConfigZonalServiceRestTransport
 
 
 class OsConfigZonalServiceClientMeta(type):
@@ -79,6 +80,7 @@ class OsConfigZonalServiceClientMeta(type):
     )  # type: Dict[str, Type[OsConfigZonalServiceTransport]]
     _transport_registry["grpc"] = OsConfigZonalServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = OsConfigZonalServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = OsConfigZonalServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -2179,7 +2181,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "OsConfigZonalServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
