@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 import warnings
 
 from google.api_core import exceptions as core_exceptions
@@ -25,7 +35,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.osconfig_v1alpha import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -174,7 +185,7 @@ class OsConfigZonalServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -211,9 +222,9 @@ class OsConfigZonalServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, OsConfigZonalServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the os config zonal service client.
@@ -257,15 +268,15 @@ class OsConfigZonalServiceAsyncClient:
 
     async def create_os_policy_assignment(
         self,
-        request: Union[
-            os_policy_assignments.CreateOSPolicyAssignmentRequest, dict
+        request: Optional[
+            Union[os_policy_assignments.CreateOSPolicyAssignmentRequest, dict]
         ] = None,
         *,
-        parent: str = None,
-        os_policy_assignment: os_policy_assignments.OSPolicyAssignment = None,
-        os_policy_assignment_id: str = None,
+        parent: Optional[str] = None,
+        os_policy_assignment: Optional[os_policy_assignments.OSPolicyAssignment] = None,
+        os_policy_assignment_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Create an OS policy assignment.
@@ -315,13 +326,13 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest, dict]]):
                 The request object. A request message to create an OS
                 policy assignment
             parent (:class:`str`):
@@ -435,14 +446,14 @@ class OsConfigZonalServiceAsyncClient:
 
     async def update_os_policy_assignment(
         self,
-        request: Union[
-            os_policy_assignments.UpdateOSPolicyAssignmentRequest, dict
+        request: Optional[
+            Union[os_policy_assignments.UpdateOSPolicyAssignmentRequest, dict]
         ] = None,
         *,
-        os_policy_assignment: os_policy_assignments.OSPolicyAssignment = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        os_policy_assignment: Optional[os_policy_assignments.OSPolicyAssignment] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Update an existing OS policy assignment.
@@ -489,13 +500,13 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest, dict]]):
                 The request object. A request message to update an OS
                 policy assignment
             os_policy_assignment (:class:`google.cloud.osconfig_v1alpha.types.OSPolicyAssignment`):
@@ -593,11 +604,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_os_policy_assignment(
         self,
-        request: Union[os_policy_assignments.GetOSPolicyAssignmentRequest, dict] = None,
+        request: Optional[
+            Union[os_policy_assignments.GetOSPolicyAssignmentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> os_policy_assignments.OSPolicyAssignment:
         r"""Retrieve an existing OS policy assignment.
@@ -633,7 +646,7 @@ class OsConfigZonalServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest, dict]]):
                 The request object. A request message to get an OS
                 policy assignment
             name (:class:`str`):
@@ -711,13 +724,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_os_policy_assignments(
         self,
-        request: Union[
-            os_policy_assignments.ListOSPolicyAssignmentsRequest, dict
+        request: Optional[
+            Union[os_policy_assignments.ListOSPolicyAssignmentsRequest, dict]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentsAsyncPager:
         r"""List the OS policy assignments under the parent
@@ -753,7 +766,7 @@ class OsConfigZonalServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest, dict]]):
                 The request object. A request message to list OS policy
                 assignments for a parent resource
             parent (:class:`str`):
@@ -829,13 +842,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_os_policy_assignment_revisions(
         self,
-        request: Union[
-            os_policy_assignments.ListOSPolicyAssignmentRevisionsRequest, dict
+        request: Optional[
+            Union[os_policy_assignments.ListOSPolicyAssignmentRevisionsRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentRevisionsAsyncPager:
         r"""List the OS policy assignment revisions for a given
@@ -869,7 +882,7 @@ class OsConfigZonalServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest, dict]]):
                 The request object. A request message to list revisions
                 for a OS policy assignment
             name (:class:`str`):
@@ -947,13 +960,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def delete_os_policy_assignment(
         self,
-        request: Union[
-            os_policy_assignments.DeleteOSPolicyAssignmentRequest, dict
+        request: Optional[
+            Union[os_policy_assignments.DeleteOSPolicyAssignmentRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Delete the OS policy assignment.
@@ -995,13 +1008,13 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest, dict]]):
                 The request object. A request message for deleting a OS
                 policy assignment.
             name (:class:`str`):
@@ -1085,13 +1098,16 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_instance_os_policies_compliance(
         self,
-        request: Union[
-            instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest, dict
+        request: Optional[
+            Union[
+                instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest,
+                dict,
+            ]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> instance_os_policies_compliance.InstanceOSPoliciesCompliance:
         r"""Get OS policies compliance data for the specified
@@ -1124,7 +1140,7 @@ class OsConfigZonalServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest, dict]]):
                 The request object. A request message for getting OS
                 policies compliance data for the given Compute Engine VM
                 instance.
@@ -1221,14 +1237,16 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_instance_os_policies_compliances(
         self,
-        request: Union[
-            instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest,
-            dict,
+        request: Optional[
+            Union[
+                instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest,
+                dict,
+            ]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstanceOSPoliciesCompliancesAsyncPager:
         r"""List OS policies compliance data for all Compute
@@ -1262,7 +1280,7 @@ class OsConfigZonalServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest, dict]]):
                 The request object. A request message for listing OS
                 policies compliance data for all Compute Engine VMs in
                 the given location.
@@ -1355,13 +1373,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_os_policy_assignment_report(
         self,
-        request: Union[
-            os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest, dict
+        request: Optional[
+            Union[os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> os_policy_assignment_reports.OSPolicyAssignmentReport:
         r"""Get the OS policy asssignment report for the
@@ -1394,7 +1412,7 @@ class OsConfigZonalServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentReportRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentReportRequest, dict]]):
                 The request object. Get a report of the OS policy
                 assignment for a VM instance.
             name (:class:`str`):
@@ -1472,13 +1490,15 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_os_policy_assignment_reports(
         self,
-        request: Union[
-            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest, dict
+        request: Optional[
+            Union[
+                os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest, dict
+            ]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentReportsAsyncPager:
         r"""List OS policy asssignment reports for all Compute
@@ -1512,7 +1532,7 @@ class OsConfigZonalServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentReportsRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentReportsRequest, dict]]):
                 The request object. List the OS policy assignment
                 reports for VM instances.
             parent (:class:`str`):
@@ -1617,11 +1637,11 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_inventory(
         self,
-        request: Union[inventory.GetInventoryRequest, dict] = None,
+        request: Optional[Union[inventory.GetInventoryRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> inventory.Inventory:
         r"""Get inventory data for the specified VM instance. If the VM has
@@ -1654,7 +1674,7 @@ class OsConfigZonalServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.GetInventoryRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.GetInventoryRequest, dict]]):
                 The request object. A request message for getting
                 inventory data for the specified VM.
             name (:class:`str`):
@@ -1735,11 +1755,11 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_inventories(
         self,
-        request: Union[inventory.ListInventoriesRequest, dict] = None,
+        request: Optional[Union[inventory.ListInventoriesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInventoriesAsyncPager:
         r"""List inventory data for all VM instances in the
@@ -1773,7 +1793,7 @@ class OsConfigZonalServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.ListInventoriesRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.ListInventoriesRequest, dict]]):
                 The request object. A request message for listing
                 inventory data for all VMs in the specified location.
             parent (:class:`str`):
@@ -1857,11 +1877,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_vulnerability_report(
         self,
-        request: Union[vulnerability.GetVulnerabilityReportRequest, dict] = None,
+        request: Optional[
+            Union[vulnerability.GetVulnerabilityReportRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> vulnerability.VulnerabilityReport:
         r"""Gets the vulnerability report for the specified VM
@@ -1895,7 +1917,7 @@ class OsConfigZonalServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest, dict]]):
                 The request object. A request message for getting the
                 vulnerability report for the specified VM.
             name (:class:`str`):
@@ -1972,11 +1994,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_vulnerability_reports(
         self,
-        request: Union[vulnerability.ListVulnerabilityReportsRequest, dict] = None,
+        request: Optional[
+            Union[vulnerability.ListVulnerabilityReportsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListVulnerabilityReportsAsyncPager:
         r"""List vulnerability reports for all VM instances in
@@ -2010,7 +2034,7 @@ class OsConfigZonalServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest, dict]):
+            request (Optional[Union[google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest, dict]]):
                 The request object. A request message for listing
                 vulnerability reports for all VM instances in the
                 specified location.
@@ -2100,14 +2124,9 @@ class OsConfigZonalServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-os-config",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("OsConfigZonalServiceAsyncClient",)
