@@ -18,17 +18,19 @@ from typing import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Iterator,
+    Optional,
     Sequence,
     Tuple,
-    Optional,
-    Iterator,
 )
 
-from google.cloud.osconfig_v1alpha.types import instance_os_policies_compliance
-from google.cloud.osconfig_v1alpha.types import inventory
-from google.cloud.osconfig_v1alpha.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1alpha.types import os_policy_assignments
-from google.cloud.osconfig_v1alpha.types import vulnerability
+from google.cloud.osconfig_v1alpha.types import (
+    instance_os_policies_compliance,
+    inventory,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
 
 
 class ListOSPolicyAssignmentsPager:
@@ -346,8 +348,10 @@ class ListInstanceOSPoliciesCompliancesPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest(
-            request
+        self._request = (
+            instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest(
+                request
+            )
         )
         self._response = response
         self._metadata = metadata
@@ -421,8 +425,10 @@ class ListInstanceOSPoliciesCompliancesAsyncPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest(
-            request
+        self._request = (
+            instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest(
+                request
+            )
         )
         self._response = response
         self._metadata = metadata
@@ -497,8 +503,8 @@ class ListOSPolicyAssignmentReportsPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(
-            request
+        self._request = (
+            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(request)
         )
         self._response = response
         self._metadata = metadata
@@ -570,8 +576,8 @@ class ListOSPolicyAssignmentReportsAsyncPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(
-            request
+        self._request = (
+            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(request)
         )
         self._response = response
         self._metadata = metadata
