@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ from typing import Dict, Type
 from .base import OsConfigZonalServiceTransport
 from .grpc import OsConfigZonalServiceGrpcTransport
 from .grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
-
+from .rest import OsConfigZonalServiceRestInterceptor, OsConfigZonalServiceRestTransport
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -27,9 +27,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[OsConfigZonalServiceTransport]]
 _transport_registry["grpc"] = OsConfigZonalServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = OsConfigZonalServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = OsConfigZonalServiceRestTransport
 
 __all__ = (
     "OsConfigZonalServiceTransport",
     "OsConfigZonalServiceGrpcTransport",
     "OsConfigZonalServiceGrpcAsyncIOTransport",
+    "OsConfigZonalServiceRestTransport",
+    "OsConfigZonalServiceRestInterceptor",
 )
